@@ -12,13 +12,14 @@ use warnings;
 
 package Dist::Zilla::Role::Git::DirtyFiles;
 {
-  $Dist::Zilla::Role::Git::DirtyFiles::VERSION = '2.021';
+  $Dist::Zilla::Role::Git::DirtyFiles::VERSION = '2.022';
 }
 # ABSTRACT: provide the allow_dirty & changelog attributes
 
 use Moose::Role;
 use Moose::Autobox;
-use MooseX::Types::Moose qw{ ArrayRef Str RegexpRef };
+use MooseX::Types::Moose qw{ Any ArrayRef Str RegexpRef };
+use MooseX::Types::Path::Tiny 0.010 qw{ Paths to_Paths };
 use Moose::Util::TypeConstraints;
 
 use namespace::autoclean;
@@ -31,11 +32,23 @@ requires qw(log_fatal repo_root zilla);
 # -- attributes
 
 
-has allow_dirty => (
-  is => 'ro', lazy => 1,
-  isa     => ArrayRef[Str],
-  builder => '_build_allow_dirty',
-);
+{
+  # We specifically allow the empty string to represent the empty list.
+  # Otherwise, there'd be no way to specify an empty list in an INI file.
+  my $type = subtype as Paths;
+  coerce($type,
+    from ArrayRef, via { to_Paths( [ grep { length } @$_ ] ) },
+    from Any, via { length($_) ? to_Paths($_) : [] },
+  );
+
+  has allow_dirty => (
+    is => 'ro', lazy => 1,
+    isa     => $type,
+    coerce  => 1,
+    builder => '_build_allow_dirty',
+  );
+}
+
 has changelog => ( is => 'ro', isa=>Str, default => 'Changes' );
 
 {
@@ -106,6 +119,8 @@ sub list_dirty_files
 
   my $allowed = join '|', $self->allow_dirty_match->flatten, map { qr{^\Q$_\E$} } @filenames;
 
+  $allowed = qr/(?!X)X/ if $allowed eq ''; # this cannot match anything
+
   return grep { /$allowed/ ? $listAllowed : !$listAllowed }
       $git->ls_files( { modified=>1, deleted=>1 } );
 } # end list_dirty_files
@@ -125,7 +140,7 @@ Dist::Zilla::Role::Git::DirtyFiles - provide the allow_dirty & changelog attribu
 
 =head1 VERSION
 
-version 2.021
+version 2.022
 
 =head1 DESCRIPTION
 
